==> pdf2djvu-0.9.1-2-src.tar.xz: pdf2djvu-0.9.1/tests/test-xmp-mediatype.py <==
# encoding=UTF-8

# Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
#
# This file is part of pdfdjvu.
#
# pdf2djvu is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# pdf2djvu is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

import xml.etree.cElementTree as etree

from tools import (
    assert_equal,
    assert_not_equal,
    assert_uuid_urn,
    case,
    xml_find_text,
)

class test(case):
    # Bug: https://bitbucket.org/jwilk/pdf2djvu/issue/12
    # + fixed in 0.6.0 [490a08283fb4]

    def test_verbatim(self):
        self.pdf2djvu('--verbatim-metadata').assert_()
        xmp = self.extract_xmp()
        xmp = etree.fromstring(xmp)
        dcformat = xml_find_text(xmp, 'dc:format')
        assert_equal(dcformat, 'application/pdf')

    def test_no_verbatim(self):
        self.require_feature('Exiv2')
        self.pdf2djvu().assert_()
        xmp = self.extract_xmp()
        xmp = etree.fromstring(xmp)
        dcformat = xml_find_text(xmp, 'dc:format')
        assert_equal(dcformat, 'image/vnd.djvu')
        instance_id = xml_find_text(xmp, 'xmpMM:InstanceID')
        document_id = xml_find_text(xmp, 'xmpMM:DocumentID')
        assert_not_equal(instance_id, document_id)
        assert_uuid_urn(instance_id)
        assert_uuid_urn(document_id)

# vim:ts=4 sts=4 sw=4 et

==> pdf2djvu-0.9.5-1-src.tar.xz: pdf2djvu-0.9.5/tests/test-xmp-mediatype.py <==
# encoding=UTF-8

# Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
#
# This file is part of pdf2djvu.
#
# pdf2djvu is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# pdf2djvu is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

import xml.etree.cElementTree as etree

from tools import (
    assert_equal,
    assert_not_equal,
    assert_uuid_urn,
    case,
    xml_find_text,
)

class test(case):
    # Bug: https://github.com/jwilk/pdf2djvu/issues/12
    # + fixed in 0.6.0 [1368c73c027d798bdbfe0ac61c26339206e747bc]

    def test_verbatim(self):
        self.pdf2djvu('--verbatim-metadata').assert_()
        xmp = self.extract_xmp()
        xmp = etree.fromstring(xmp)
        dcformat = xml_find_text(xmp, 'dc:format')
        assert_equal(dcformat, 'application/pdf')

    def test_no_verbatim(self):
        self.require_feature('Exiv2')
        self.pdf2djvu().assert_()
        xmp = self.extract_xmp()
        xmp = etree.fromstring(xmp)
        dcformat = xml_find_text(xmp, 'dc:format')
        assert_equal(dcformat, 'image/vnd.djvu')
        instance_id = xml_find_text(xmp, 'xmpMM:InstanceID')
        document_id = xml_find_text(xmp, 'xmpMM:DocumentID')
        assert_not_equal(instance_id, document_id)
        assert_uuid_urn(instance_id)
        assert_uuid_urn(document_id)

# vim:ts=4 sts=4 sw=4 et
